@@ -7,7 +7,10 @@ except ImportError:
 
 from peewee import ImproperlyConfigured
 from peewee import MySQLDatabase
+from peewee import NodeList
+from peewee import SQL
 from peewee import TextField
+from peewee import fn
 
 
 class MySQLConnectorDatabase(MySQLDatabase):
@@ -32,3 +35,12 @@ class JSONField(TextField):
     def python_value(self, value):
         if value is not None:
             return json.loads(value)
+
+
+def Match(columns, expr, modifier=None):
+    if isinstance(columns, (list, tuple)):
+        match = fn.MATCH(*columns)  # Tuple of one or more columns / fields.
+    else:
+        match = fn.MATCH(columns)  # Single column / field.
+    args = expr if modifier is None else NodeList((expr, SQL(modifier)))
+    return NodeList((match, fn.AGAINST(args)))
